@@ -59,6 +59,8 @@ FlatpakResource::FlatpakResource(const AppStream::Component &component, FlatpakI
     , m_state(AbstractResource::None)
     , m_type(FlatpakResource::DesktopApp)
 {
+    setObjectName(component.id());
+
     // Start fetching remote icons during initialization
     const auto icons = m_appdata.icons();
     if (!icons.isEmpty()) {
@@ -269,7 +271,7 @@ QString FlatpakResource::longDescription()
     return m_appdata.description();
 }
 
-QString FlatpakResource::name()
+QString FlatpakResource::name() const
 {
     QString name = m_appdata.name();
     if (name.isEmpty()) {
@@ -369,13 +371,10 @@ QString FlatpakResource::typeAsString() const
 
 QString FlatpakResource::uniqueId() const
 {
-    // Build uniqueId
-    return QString::fromUtf8("%1/%2/%3/%4/%5/%6").arg(installationPath())
-                                                 .arg(QLatin1String("flatpak"))
-                                                 .arg(origin())
-                                                 .arg(typeAsString())
-                                                 .arg(m_appdata.id())
-                                                 .arg(branch());
+    return installationPath() + QStringLiteral("/flatpak/") + origin()
+                              + QLatin1Char('/') + typeAsString()
+                              + QLatin1Char('/') + m_appdata.id()
+                              + QLatin1Char('/') + branch();
 }
 
 void FlatpakResource::invokeApplication() const
@@ -396,10 +395,7 @@ void FlatpakResource::invokeApplication() const
 
 void FlatpakResource::fetchChangelog()
 {
-    QString log = longDescription();
-    log.replace(QLatin1Char('\n'), QLatin1String("<br />"));
-
-    emit changelogFetched(log);
+    emit changelogFetched(AppStreamUtils::changelogToHtml(m_appdata));
 }
 
 void FlatpakResource::fetchScreenshots()
