@@ -41,9 +41,16 @@ AppPackageKitResource::AppPackageKitResource(const AppStream::Component& data, c
     Q_ASSERT(data.isValid());
 }
 
-QString AppPackageKitResource::name()
+QString AppPackageKitResource::name() const
 {
-    return m_appdata.name();
+    QString ret;
+    if (!m_appdata.extends().isEmpty()) {
+        auto components = backend()->componentsById(m_appdata.extends().constFirst());
+        Q_ASSERT(!components.isEmpty());
+        ret = components.constFirst().name() + QStringLiteral(" - ") + m_appdata.name();
+    } else
+        ret = m_appdata.name();
+    return ret;
 }
 
 QString AppPackageKitResource::longDescription()
@@ -174,12 +181,7 @@ QStringList AppPackageKitResource::extends() const
 
 void AppPackageKitResource::fetchChangelog()
 {
-    QString changelog;
-    for(const auto& rel: m_appdata.releases()) {
-        changelog += QStringLiteral("<h3>") + rel.version() + QStringLiteral("</h3>");
-        changelog += QStringLiteral("<p>") + rel.description() + QStringLiteral("</p>");
-    }
-    emit changelogFetched(changelog);
+    emit changelogFetched(AppStreamUtils::changelogToHtml(m_appdata));
 }
 
 void AppPackageKitResource::invokeApplication() const
