@@ -152,7 +152,7 @@ void PackageKitBackend::reloadPackageList()
                 }
             }
 
-            qDebug() << "no packages for" << component.name();
+            qDebug() << "no packages for" << component.id();
             continue;
         }
         neededPackages += pkgNames;
@@ -337,6 +337,11 @@ void PackageKitBackend::refreshDatabase()
     }
 }
 
+QList<AppStream::Component> PackageKitBackend::componentsById(const QString& id) const
+{
+    return m_appdata.componentsById(id);
+}
+
 ResultsStream* PackageKitBackend::search(const AbstractResourcesBackend::Filters& filter)
 {
     if (!filter.resourceUrl.isEmpty()) {
