@@ -74,6 +74,8 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         bool hasApplications() const override { return true; }
         static QString locateService(const QString &filename);
 
+        QList<AppStream::Component> componentsById(const QString &id) const;
+
     public Q_SLOTS:
         void reloadPackageList();
         void refreshDatabase();
@@ -90,10 +92,8 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         void getUpdatesDetailsFinished(PackageKit::Transaction::Exit,uint);
 
     private:
-        void delayedInit();
-
-        template <typename T>
-        T resourcesByPackageNames(const QStringList& names) const;
+        template <typename T, typename Q>
+        T resourcesByPackageNames(const Q& names) const;
         void fetchUpdates();
 
         void checkDaemonRunning();
