@@ -72,9 +72,6 @@ void ResourcesModel::init(bool load)
     m_updateAction->setIcon(QIcon::fromTheme(QStringLiteral("system-software-update")));
     m_updateAction->setText(i18nc("@action Checks the Internet for updates", "Check for Updates"));
     m_updateAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_R));
-    connect(this, &ResourcesModel::fetchingChanged, m_updateAction, [this](bool fetching) {
-        m_updateAction->setEnabled(!fetching);
-    });
     connect(m_updateAction, &QAction::triggered, this, &ResourcesModel::checkForUpdates);
 }
 
@@ -131,7 +128,7 @@ void ResourcesModel::callerFetchingChanged()
         int idx = m_backends.indexOf(backend);
         Q_ASSERT(idx>=0);
         m_backends.removeAt(idx);
-//         Q_EMIT backendsChanged();
+        Q_EMIT backendsChanged();
         CategoryModel::global()->blacklistPlugin(backend->name());
         backend->deleteLater();
         return;
@@ -343,7 +340,8 @@ AbstractResource* ResourcesModel::resourceForFile(const QUrl& file)
 void ResourcesModel::checkForUpdates()
 {
     for(auto backend: qAsConst(m_backends))
-        backend->checkForUpdates();
+        if (!backend->isFetching())
+            backend->checkForUpdates();
 }
 
 QVector<AbstractResourcesBackend *> ResourcesModel::applicationBackends() const
